@@ -28,6 +28,9 @@ y = H(:,1);
 X = H(:,2:end);
 
 b=(X\y);
+if any(isnan(b)) || any(isinf(b)),
+    b=0;
+end
 yhat =  X*b;
 if rank(yhat),
     co = abs(y'*yhat/sqrt((y'*y)*(yhat'*yhat)));
