@@ -12,7 +12,7 @@ function dynare_estimation_1(var_list_,dname)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2003-2012 Dynare Team
+% Copyright (C) 2003-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -106,6 +106,20 @@ if ~isempty(options_.mode_file) && ~options_.mh_posterior_mode_estimation
     load(options_.mode_file);
 end
 
+%% load optimal_mh_scale parameter if previous run was with
+%% mode_compute=6
+mh_scale_fname = [M_.fname '_optimal_mh_scale_parameter.mat'];
+if exist(mh_scale_fname)
+    if options_.mode_compute == 0
+        tmp = load(mh_scale_fname,'Scale');
+        bayestopt_.mh_jscale = tmp.Scale;
+        clear tmp;
+    else
+        % remove the file if mode_compute ~= 0
+        delete('mh_scale_fname')
+    end
+end
+
 if ~isempty(estim_params_)
     set_parameters(xparam1);
 end
@@ -170,29 +184,36 @@ if isequal(options_.mode_compute,0) && isempty(options_.mode_file) && options_.m
     return
 end
 
-if isequal(options_.mode_compute,6)
-    % Erase previously computed optimal mh scale parameter.
-    delete([M_.fname '_optimal_mh_scale_parameter.mat'])
-end
-
 
 %% Estimation of the posterior mode or likelihood mode
 if ~isequal(options_.mode_compute,0) && ~options_.mh_posterior_mode_estimation
     switch options_.mode_compute
       case 1
+        if exist('OCTAVE_VERSION')
+            error('Option mode_compute=1 is not available under Octave')
+        elseif ~user_has_matlab_license('optimization_toolbox')
+            error('Option mode_compute=1 requires the Optimization Toolbox')
+        end
+
         optim_options = optimset('display','iter','LargeScale','off', ...
                                  'MaxFunEvals',100000,'TolFun',1e-8,'TolX',1e-6);
         if isfield(options_,'optim_opt')
             eval(['optim_options = optimset(optim_options,' options_.optim_opt ');']);
         end
         if options_.analytic_derivation,
-            optim_options = optimset(optim_options,'GradObj','on');
+            optim_options = optimset(optim_options,'GradObj','on','TolX',1e-7);
         end
             [xparam1,fval,exitflag,output,lamdba,grad,hessian_fmincon] = ...
                 fmincon(objective_function,xparam1,[],[],[],[],lb,ub,[],optim_options,dataset_,options_,M_,estim_params_,bayestopt_,oo_);
       case 2
         error('ESTIMATION: mode_compute=2 option (Lester Ingber''s Adaptive Simulated Annealing) is no longer available')
       case 3
+        if exist('OCTAVE_VERSION') && ~user_has_octave_forge_package('optim')
+            error('Option mode_compute=3 requires the optim package')
+        elseif ~exist('OCTAVE_VERSION') && ~user_has_matlab_license('optimization_toolbox')
+            error('Option mode_compute=3 requires the Optimization Toolbox')
+        end
+
         optim_options = optimset('display','iter','MaxFunEvals',100000,'TolFun',1e-8,'TolX',1e-6);
         if isfield(options_,'optim_opt')
             eval(['optim_options = optimset(optim_options,' options_.optim_opt ');']);
@@ -200,7 +221,14 @@ if ~isequal(options_.mode_compute,0) && ~options_.mh_posterior_mode_estimation
         if options_.analytic_derivation,
             optim_options = optimset(optim_options,'GradObj','on');
         end
-        [xparam1,fval,exitflag] = fminunc(objective_function,xparam1,optim_options,dataset_,options_,M_,estim_params_,bayestopt_,oo_);
+        if ~exist('OCTAVE_VERSION')
+            [xparam1,fval,exitflag] = fminunc(objective_function,xparam1,optim_options,dataset_,options_,M_,estim_params_,bayestopt_,oo_);
+        else
+            % Under Octave, use a wrapper, since fminunc() does not have a 4th arg
+            func = @(x) objective_function(x, dataset_,options_,M_,estim_params_,bayestopt_,oo_);
+            [xparam1,fval,exitflag] = fminunc(func,xparam1,optim_options);
+        end
+
       case 4
         H0 = 1e-4*eye(nx);
         crit = 1e-7;
@@ -317,6 +345,12 @@ if ~isequal(options_.mode_compute,0) && ~options_.mh_posterior_mode_estimation
         end
       case 7
         % Matlab's simplex (Optimization toolbox needed).
+        if exist('OCTAVE_VERSION') && ~user_has_octave_forge_package('optim')
+            error('Option mode_compute=7 requires the optim package')
+        elseif ~exist('OCTAVE_VERSION') && ~user_has_matlab_license('optimization_toolbox')
+            error('Option mode_compute=7 requires the Optimization Toolbox')
+        end
+
         optim_options = optimset('display','iter','MaxFunEvals',1000000,'MaxIter',6000,'TolFun',1e-8,'TolX',1e-6);
         if isfield(options_,'optim_opt')
             eval(['optim_options = optimset(optim_options,' options_.optim_opt ');']);
@@ -426,7 +460,10 @@ if ~options_.mh_posterior_mode_estimation && options_.cova_compute
 end
 
 if options_.mode_check == 1 && ~options_.mh_posterior_mode_estimation
+    ana_deriv = options_.analytic_derivation;
+    options_.analytic_derivation = 0;
     mode_check(objective_function,xparam1,hh,dataset_,options_,M_,estim_params_,bayestopt_,oo_);
+    options_.analytic_derivation = ana_deriv;
 end
 
 oo_.posterior.optimization.mode = xparam1;
@@ -888,7 +925,9 @@ if (any(bayestopt_.pshape  >0 ) && options_.mh_replic) || ...
         if options_.mh_replic
             [marginal,oo_] = marginal_density(M_, options_, estim_params_, oo_);
             oo_ = GetPosteriorParametersStatistics(estim_params_, M_, options_, bayestopt_, oo_);
-            oo_ = PlotPosteriorDistributions(estim_params_, M_, options_, bayestopt_, oo_);
+            if ~options_.nograph
+                oo_ = PlotPosteriorDistributions(estim_params_, M_, options_, bayestopt_, oo_);
+            end
             [oo_.posterior.metropolis.mean,oo_.posterior.metropolis.variance] ...
                 = GetPosteriorMeanVariance(M_,options_.mh_drop);
         else
@@ -947,6 +986,9 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
         eval(['oo_.UpdatedVariables.' deblank(M_.endo_names(i1,:)) ...
               ' = updated_variables(i,:)'';']);
     end
+    for i=1:M_.exo_nbr
+        eval(['oo_.SmoothedShocks.' deblank(M_.exo_names(i,:)) ' = innov(i,:)'';']);
+    end
     if ~options_.nograph,
         [nbplt,nr,nc,lr,lc,nstar] = pltorg(M_.exo_nbr);
         if options_.TeX
@@ -987,7 +1029,6 @@ if (~((any(bayestopt_.pshape > 0) && options_.mh_replic) || (any(bayestopt_.psha
                     end
                 end
                 title(name,'Interpreter','none')
-                eval(['oo_.SmoothedShocks.' deblank(name) ' = innov(k,:)'';']);
             end
             dyn_saveas(hh,[M_.fname '_SmoothedShocks' int2str(plt)],options_);
             if options_.TeX
