@@ -60,6 +60,17 @@ options_ident = set_default_option(options_ident,'replic',100);
 options_ident = set_default_option(options_ident,'advanced',0);
 options_ident = set_default_option(options_ident,'normalize_jacobians',1);
 options_ident = set_default_option(options_ident,'lik_init',1);
+options_ident = set_default_option(options_ident,'analytic_derivation',1);
+if isfield(options_ident,'nograph'),
+    options_.nograph=options_ident.nograph;
+end
+if isfield(options_ident,'nodisplay'),
+    options_.nodisplay=options_ident.nodisplay;
+end
+if isfield(options_ident,'graph_format'),
+    options_.graph_format=options_ident.graph_format;
+end
+
 if options_ident.gsa_sample_file,
     GSAFolder = checkpath('gsa',M_.dname);
     if options_ident.gsa_sample_file==1,
@@ -117,6 +128,7 @@ options_ = set_default_option(options_,'datafile',[]);
 options_.mode_compute = 0;
 options_.plot_priors = 0;
 [dataset_,xparam1, M_, options_, oo_, estim_params_,bayestopt_]=dynare_estimation_init(M_.endo_names,fname_,1, M_, options_, oo_, estim_params_, bayestopt_);
+options_ident.analytic_derivation_mode = options_.analytic_derivation_mode;
 if isempty(dataset_),
     dataset_.info.ntobs = periods;
     dataset_.info.nvobs = rows(options_.varobs);
@@ -256,8 +268,18 @@ if iload <=0,
         parameters = 'Current_params';
         disp('Testing current parameter values')
     end
-    [idehess_point, idemoments_point, idemodel_point, idelre_point, derivatives_info_point] = ...
+    [idehess_point, idemoments_point, idemodel_point, idelre_point, derivatives_info_point, info] = ...
         identification_analysis(params,indx,indexo,options_ident,dataset_, prior_exist, name_tex,1);
+    if info(1)~=0,
+        disp(' ')
+        disp('----------- ')
+        disp('Parameter error:')
+        disp(['The model does not solve for ', parameters, ' with error code info = ', int2str(info(1))]),
+        disp('Identification stopped ')
+        disp('----------- ')
+        disp(' ')
+        return,
+    else
     idehess_point.params=params;
 %     siH = idemodel_point.siH;
 %     siJ = idemoments_point.siJ;
@@ -270,6 +292,7 @@ if iload <=0,
     if ~options_.nograph,
         plot_identification(params,idemoments_point,idehess_point,idemodel_point,idelre_point,advanced,parameters,name,IdentifDirectoryName);
     end
+    end
 
     if SampleSize > 1,
         disp(' ')
@@ -294,7 +317,7 @@ if iload <=0,
         end
         [dum1, ideJ, ideH, ideGP, dum2 , info] = ...
             identification_analysis(params,indx,indexo,options_MC,dataset_, prior_exist, name_tex,0);
-        if iteration==0,
+        if iteration==0 && info(1)==0,
             MAX_tau   = min(SampleSize,ceil(MaxNumberOfBytes/(size(ideH.siH,1)*nparam)/8));
             stoH = zeros([size(ideH.siH,1),nparam,MAX_tau]);
             stoJJ = zeros([size(ideJ.siJ,1),nparam,MAX_tau]);
