@@ -34,6 +34,12 @@ options_gsa = set_default_option(options_gsa,'datafile',[]);
 if isfield(options_gsa,'nograph'),
     options_.nograph=options_gsa.nograph;
 end
+if isfield(options_gsa,'nodisplay'),
+    options_.nodisplay=options_gsa.nodisplay;
+end
+if isfield(options_gsa,'graph_format'),
+    options_.graph_format=options_gsa.graph_format;
+end
 if isfield(options_gsa,'mode_file'),
     options_.mode_file=options_gsa.mode_file;
 end
@@ -128,7 +134,7 @@ options_gsa = set_default_option(options_gsa,'pvalue_corr',0.001);
 options_gsa = set_default_option(options_gsa,'logtrans_redform',0);
 options_gsa = set_default_option(options_gsa,'threshold_redform',[]);
 options_gsa = set_default_option(options_gsa,'ksstat_redform',0.001);
-options_gsa = set_default_option(options_gsa,'alpha2_redform',0.001);
+options_gsa = set_default_option(options_gsa,'alpha2_redform',0);
 options_gsa = set_default_option(options_gsa,'namendo',[]);
 options_gsa = set_default_option(options_gsa,'namlagendo',[]);
 options_gsa = set_default_option(options_gsa,'namexo',[]);
@@ -139,7 +145,7 @@ options_gsa = set_default_option(options_gsa,'var_rmse',options_.varobs);
 options_gsa = set_default_option(options_gsa,'pfilt_rmse',0.1);
 options_gsa = set_default_option(options_gsa,'istart_rmse',options_.presample+1);
 options_gsa = set_default_option(options_gsa,'alpha_rmse',0.001);
-options_gsa = set_default_option(options_gsa,'alpha2_rmse',0.001);
+options_gsa = set_default_option(options_gsa,'alpha2_rmse',0);
 
 if options_gsa.redform && options_gsa.neighborhood_width==0 && isempty(options_gsa.threshold_redform),
     options_gsa.pprior=1;
