@@ -214,11 +214,16 @@ particle.mixture_measurement_shocks = 1 ;
 % Copy ep structure in options_ global structure
 options_.particle = particle;
 
+% Simulation of stochastic non linear stochastic models.
+bnlms.innovation_distribution = 'gaussian';
+bnlms.set_dynare_seed_to_default = 1;
+options_.bnlms = bnlms;
+
 % TeX output
 options_.TeX = 0;
 
 % Exel
-options_.xls_sheet = '';
+options_.xls_sheet = 1; % Octave does not support the empty string, rather use first sheet
 options_.xls_range = '';
 
 % Prior draws
@@ -315,6 +320,7 @@ options_.MaxNumberOfBytes = 1e6;
 options_.MaximumNumberOfMegaBytes = 111;
 options_.PosteriorSampleSize = 1000;
 options_.analytic_derivation = 0;
+options_.analytic_derivation_mode = 0;
 options_.bayesian_irf = 0;
 options_.bayesian_th_moments = 0;
 options_.diffuse_filter = 0;
