@@ -161,6 +161,13 @@ ModFile::checkPass()
       exit(EXIT_FAILURE);
     }
 
+  if ((block || byte_code) && stochastic_statement_present
+      && mod_file_struct.order_option >= 2)
+    {
+      cerr << "ERROR: In 'model' block, 'block' and/or 'bytecode' options are not yet compatible with a stochastic model at order >= 2" << endl;
+      exit(EXIT_FAILURE);
+    }
+
   if (use_dll && (block || byte_code))
     {
       cerr << "ERROR: In 'model' block, 'use_dll' option is not compatible with 'block' or 'bytecode'" << endl;
@@ -377,10 +384,11 @@ ModFile::computingPass(bool no_tmp_terms)
               || mod_file_struct.estimation_present || mod_file_struct.osr_present
               || mod_file_struct.ramsey_policy_present || mod_file_struct.identification_present)
             static_model.set_cutoff_to_zero();
-          if (mod_file_struct.identification_present)
-            static_model.computingPass(global_eval_context, no_tmp_terms, true, block, byte_code);
-          else
-            static_model.computingPass(global_eval_context, no_tmp_terms, false, block, byte_code);
+
+          const bool static_hessian = mod_file_struct.identification_present
+            || mod_file_struct.estimation_analytic_derivation;
+          static_model.computingPass(global_eval_context, no_tmp_terms, static_hessian,
+                                     block, byte_code);
         }
       // Set things to compute for dynamic model
       if (mod_file_struct.simul_present || mod_file_struct.check_present
@@ -402,7 +410,7 @@ ModFile::computingPass(bool no_tmp_terms)
                   exit(EXIT_FAILURE);
                 }
               bool hessian = mod_file_struct.order_option >= 2 || mod_file_struct.identification_present || mod_file_struct.estimation_analytic_derivation;
-              bool thirdDerivatives = mod_file_struct.order_option == 3;
+              bool thirdDerivatives = mod_file_struct.order_option == 3 || mod_file_struct.estimation_analytic_derivation;
               bool paramsDerivatives = mod_file_struct.identification_present || mod_file_struct.estimation_analytic_derivation;
               dynamic_model.computingPass(true, hessian, thirdDerivatives, paramsDerivatives, global_eval_context, no_tmp_terms, block, use_dll, byte_code);
             }
